@@ -316,9 +316,11 @@ gda_client_open_connection (GdaClient *client,
 	/* search for the connection in our private list */
 	if (! (options & GDA_CONNECTION_OPTIONS_DONT_SHARE)) {
 		cnc = gda_client_find_connection (client, dsn, username, password);
-		if (cnc) {
+		if (cnc &&
+		    ! (gda_connection_get_options (cnc) & GDA_CONNECTION_OPTIONS_DONT_SHARE)) {
 			g_object_ref (G_OBJECT (cnc));
 			gda_client_notify_connection_opened_event (client, cnc);
+			gda_config_free_data_source_info (dsn_info);
 			return cnc;
 		}
 	}
@@ -345,7 +347,7 @@ gda_client_open_connection (GdaClient *client,
 		/* load the new provider */
 		prv = g_new0 (LoadedProvider, 1);
 		prv->handle = g_module_open (prv_info->location, G_MODULE_BIND_LAZY);
-		gda_config_free_provider_info (prv_info);
+		gda_provider_info_free (prv_info);
 		if (!prv->handle) {
 			emit_client_error (client, NULL, g_module_error ());
 			gda_config_free_data_source_info (dsn_info);
@@ -418,7 +420,11 @@ gda_client_open_connection (GdaClient *client,
  * Opens a connection given a provider ID and a connection string. This
  * allows applications to open connections without having to create
  * a data source in the configuration. The format of @cnc_string is
- * similar to PostgreSQL and MySQL connection strings.
+ * similar to PostgreSQL and MySQL connection strings. It is a ;-separated
+ * series of key=value pairs. Do not add extra whitespace after the ; 
+ * separator. The possible keys depend on the provider, but
+ * these keys should work with all providers:
+ * USER, PASSWORD, HOST, DATABASE, PORT
  *
  * Returns: the opened connection if successful, %NULL if there is
  * an error.
@@ -432,9 +438,24 @@ gda_client_open_connection_from_string (GdaClient *client,
 	GdaDataSourceInfo *dsn_info;
 	GdaConnection *cnc;
 	static gint count = 0;
+	GList *l;
 
 	g_return_val_if_fail (GDA_IS_CLIENT (client), NULL);
 	g_return_val_if_fail (provider_id != NULL, NULL);
+	
+	if (! (options & GDA_CONNECTION_OPTIONS_DONT_SHARE)) {
+		for (l = client->priv->connections; l != NULL; l = l->next) {
+			const gchar *tmp_prov, *tmp_cnc_string;
+	
+			cnc = GDA_CONNECTION (l->data);
+			tmp_prov = gda_connection_get_provider (cnc);
+			tmp_cnc_string = gda_connection_get_cnc_string (cnc);
+	
+			if (strcmp(provider_id, tmp_prov) == 0
+			    && (cnc_string != NULL && strcmp (cnc_string, tmp_cnc_string) == 0))
+				return cnc;
+		}
+	}
 
 	/* create a temporary DSNInfo */
 	dsn_info = g_new (GdaDataSourceInfo, 1);
@@ -453,7 +474,8 @@ gda_client_open_connection_from_string (GdaClient *client,
 				     dsn_info->password);
 
 	/* open the connection */
-	cnc = gda_client_open_connection (client, dsn_info->name,
+	cnc = gda_client_open_connection (client,
+					  dsn_info->name,
 					  dsn_info->username,
 					  dsn_info->password,
 					  options);
@@ -526,7 +548,7 @@ gda_client_find_connection (GdaClient *client,
 		tmp_usr = gda_connection_get_username (cnc);
 		tmp_pwd = gda_connection_get_password (cnc);
 
-		if (((!tmp_dsn && !dsn_info->cnc_string) || !strcmp (tmp_dsn, dsn_info->cnc_string)) &&
+		if (((!tmp_dsn && !dsn_info->name) || !strcmp (tmp_dsn, dsn_info->name)) &&
 		    ((!tmp_usr && !username) || !strcmp (tmp_usr, username)) &&
 		    ((!tmp_pwd && !password) || !strcmp (tmp_pwd, password))) {
 			gda_config_free_data_source_info (dsn_info);
