@@ -36,21 +36,21 @@
      L_FROM = 259,
      L_WHERE = 260,
      L_AS = 261,
-     L_JOIN = 262,
-     L_ON = 263,
-     L_ORDER = 264,
-     L_BY = 265,
-     L_DISTINCT = 266,
-     L_BETWEEN = 267,
-     L_IN = 268,
-     L_GROUP = 269,
-     L_INSERT = 270,
-     L_INTO = 271,
-     L_VALUES = 272,
-     L_UPDATE = 273,
-     L_SET = 274,
-     L_DOT = 275,
-     L_STAR = 276,
+     L_ON = 262,
+     L_ORDER = 263,
+     L_BY = 264,
+     L_ORDER_ASC = 265,
+     L_ORDER_DSC = 266,
+     L_DISTINCT = 267,
+     L_BETWEEN = 268,
+     L_IN = 269,
+     L_GROUP = 270,
+     L_INSERT = 271,
+     L_INTO = 272,
+     L_VALUES = 273,
+     L_UPDATE = 274,
+     L_SET = 275,
+     L_DOT = 276,
      L_COMMA = 277,
      L_NULL = 278,
      L_LBRACKET = 279,
@@ -59,35 +59,55 @@
      L_EQ = 282,
      L_IS = 283,
      L_LIKE = 284,
-     L_NOT = 285,
-     L_AND = 286,
-     L_OR = 287,
-     L_MINUS = 288,
-     L_PLUS = 289,
-     L_TIMES = 290,
-     L_DIV = 291,
-     L_STRING = 292
+     L_GT = 285,
+     L_LT = 286,
+     L_GEQ = 287,
+     L_LEQ = 288,
+     L_DIFF = 289,
+     L_NOT = 290,
+     L_AND = 291,
+     L_OR = 292,
+     L_MINUS = 293,
+     L_PLUS = 294,
+     L_TIMES = 295,
+     L_DIV = 296,
+     L_STRING = 297,
+     L_TEXTUAL = 298,
+     L_DELETE = 299,
+     L_JOIN = 300,
+     L_INNER = 301,
+     L_LEFT = 302,
+     L_RIGHT = 303,
+     L_FULL = 304,
+     L_OUTER = 305,
+     L_LSBRACKET = 306,
+     L_RSBRACKET = 307,
+     L_PNAME = 308,
+     L_PTYPE = 309,
+     L_PISPARAM = 310,
+     L_PDESCR = 311,
+     L_PNULLOK = 312
    };
 #endif
 #define L_SELECT 258
 #define L_FROM 259
 #define L_WHERE 260
 #define L_AS 261
-#define L_JOIN 262
-#define L_ON 263
-#define L_ORDER 264
-#define L_BY 265
-#define L_DISTINCT 266
-#define L_BETWEEN 267
-#define L_IN 268
-#define L_GROUP 269
-#define L_INSERT 270
-#define L_INTO 271
-#define L_VALUES 272
-#define L_UPDATE 273
-#define L_SET 274
-#define L_DOT 275
-#define L_STAR 276
+#define L_ON 262
+#define L_ORDER 263
+#define L_BY 264
+#define L_ORDER_ASC 265
+#define L_ORDER_DSC 266
+#define L_DISTINCT 267
+#define L_BETWEEN 268
+#define L_IN 269
+#define L_GROUP 270
+#define L_INSERT 271
+#define L_INTO 272
+#define L_VALUES 273
+#define L_UPDATE 274
+#define L_SET 275
+#define L_DOT 276
 #define L_COMMA 277
 #define L_NULL 278
 #define L_LBRACKET 279
@@ -96,14 +116,34 @@
 #define L_EQ 282
 #define L_IS 283
 #define L_LIKE 284
-#define L_NOT 285
-#define L_AND 286
-#define L_OR 287
-#define L_MINUS 288
-#define L_PLUS 289
-#define L_TIMES 290
-#define L_DIV 291
-#define L_STRING 292
+#define L_GT 285
+#define L_LT 286
+#define L_GEQ 287
+#define L_LEQ 288
+#define L_DIFF 289
+#define L_NOT 290
+#define L_AND 291
+#define L_OR 292
+#define L_MINUS 293
+#define L_PLUS 294
+#define L_TIMES 295
+#define L_DIV 296
+#define L_STRING 297
+#define L_TEXTUAL 298
+#define L_DELETE 299
+#define L_JOIN 300
+#define L_INNER 301
+#define L_LEFT 302
+#define L_RIGHT 303
+#define L_FULL 304
+#define L_OUTER 305
+#define L_LSBRACKET 306
+#define L_RSBRACKET 307
+#define L_PNAME 308
+#define L_PTYPE 309
+#define L_PISPARAM 310
+#define L_PDESCR 311
+#define L_PNULLOK 312
 
 
 
@@ -111,18 +151,20 @@
 #ifndef YYSTYPE
 #line 17 "parser.y"
 typedef union {
-void *v;
-char *str;
-int i;
-GList *list;
-sql_field *f;
-sql_field_item *fi;
-sql_table *t;
-sql_condition *c;
-sql_where *w;
+void            *v;
+char            *str;
+int              i;
+GList           *list;
+sql_field       *f;
+sql_field_item  *fi;
+sql_table       *t;
+sql_condition   *c;
+sql_where       *w;
+param_spec      *ps;
+sql_order_field *of;
 } yystype;
 /* Line 1281 of /usr/share/bison/yacc.c.  */
-#line 126 "parser.h"
+#line 168 "parser.h"
 # define YYSTYPE yystype
 #endif
 
